@@ -21,8 +21,8 @@
 #ifndef __KGAMEPROPERTY_H_
 #define __KGAMEPROPERTY_H_
 
-#include <QtCore/QDataStream>
-#include <QtCore/QDebug>
+#include <QDataStream>
+#include <QDebug>
 
 #include <typeinfo>
 #include "libkdegamesprivate_export.h"
@@ -121,7 +121,7 @@ public:
 	/**
 	 * Constructs a KGamePropertyBase object and calls registerData.
 	 * @param id The id of this property. MUST be UNIQUE! Used to send and
-	 * receive changes in the property of the playere automatically via
+	 * receive changes in the property of the player automatically via
 	 * network.
 	 * @param owner The owner of the object. Must be a KGamePropertyHandler which manages
 	 * the changes made to this object, i.e. which will send the new data
@@ -229,7 +229,7 @@ public:
 
 	/**
 	 * send a command to advanced properties like arrays
-	 * @param stream The stream containing the data of the comand
+	 * @param stream The stream containing the data of the command
 	 * @param msgid The ID of the command - see PropertyCommandIds
 	 * @param isSender whether this client is also the sender of the command
 	 **/
@@ -241,7 +241,7 @@ public:
 	int id() const { return mId; }
 
 	/**
-	 * @return a type_info of the data this property contains. 
+	 * @return a type_info of the data this property contains.
 	 **/
 	virtual const type_info* typeinfo() { return &typeid(this); }
 
@@ -390,7 +390,7 @@ private:
  * Note: The entire API documentation is obsolete!
  *
  * The class KGameProperty can store any form of data and will transmit it via
- * network whenver you call send. This makes network transparent games
+ * network whenever you call send. This makes network transparent games
  * very easy. You first have to register the data to a KGamePropertyHandler
  * using KGamePropertyBase::registerData (which is called by the
  * constructor). For the KGamePropertyHandler you can use
@@ -451,7 +451,7 @@ private:
  * KGameProperty objects are ensured to have the same value on all clients in
  * the game at every time. This way you will save you a lot of trouble as
  * debugging can be very difficult if the value of a property changes
- * immediately on client A but only after one or two additianal messages
+ * immediately on client A but only after one or two additional messages
  * (function calls, status changes, ...) on client B.
  *
  * The only disadvantage of this (clean) concept is that you cannot use a
@@ -659,7 +659,7 @@ public:
 	 * the property which can be deactivated by setEmittingSignal because of
 	 * performance (you probably don't have to deactivate it - except you
 	 * want to write a real-time game like Command&Conquer with a lot of
-	 * acitvity). See emitSignal
+	 * activity). See emitSignal
 	 *
 	 * Note that if there is no KMessageServer accessible - before
 	 * the property has been registered to the KGamePropertyHandler (as
@@ -755,7 +755,7 @@ public:
 	 * Saves the object to a stream.
 	 * @param stream The stream to save to
 	 **/
-	virtual void save(QDataStream &stream)
+	void save(QDataStream &stream) Q_DECL_OVERRIDE
 	{
 		stream << mData;
 	}
@@ -781,7 +781,7 @@ public:
 	 * Also calls emitSignal if isEmittingSignal is TRUE.
 	 * @param s The stream to read from
 	 **/
-	virtual void load(QDataStream& s)
+	void load(QDataStream& s) Q_DECL_OVERRIDE
 	{
 		s >> mData;
 		setDirty(false);
@@ -834,7 +834,7 @@ public:
 	 **/
 	operator type() const { return value(); }
 
-	virtual const type_info* typeinfo() { return &typeid(type); }
+	const type_info* typeinfo() Q_DECL_OVERRIDE { return &typeid(type); }
 
 private:
 	void init() { }
